NAME
Catalyst::Dispatcher - The Catalyst Dispatcher
SYNOPSIS
See Catalyst.
DESCRIPTION
METHODS
$self->preload_dispatch_types
An arrayref of pre-loaded dispatchtype classes
Entries are considered to be available as Catalyst::DispatchType::CLASS To use a custom class outside the regular Catalyst namespace, prefix it with a +, like so:
+My::Dispatch::Type
$self->postload_dispatch_types
An arrayref of post-loaded dispatchtype classes
Entries are considered to be available as Catalyst::DispatchType::CLASS To use a custom class outside the regular Catalyst namespace, prefix it with a +, like so:
+My::Dispatch::Type
$self->detach( $c, $command [, \@arguments ] )
$self->dispatch($c)
$self->forward( $c, $command [, \@arguments ] )
$self->prepare_action($c)
$self->get_action( $action, $namespace )
$self->get_actions( $c, $action, $namespace )
$self->get_containers( $namespace )
$self->register( $c, $action )
$self->setup_actions( $class, $component )
AUTHOR
Sebastian Riedel, sri@cpan.org Matt S Trout, mst@shadowcatsystems.co.uk
COPYRIGHT
This program is free software, you can redistribute it and/or modify it under the same terms as Perl itself.